summaryrefslogtreecommitdiff
path: root/src/dcp.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dcp.h')
-rw-r--r--src/dcp.h13
1 files changed, 8 insertions, 5 deletions
diff --git a/src/dcp.h b/src/dcp.h
index 8086f4de..7da08eff 100644
--- a/src/dcp.h
+++ b/src/dcp.h
@@ -69,15 +69,16 @@ public:
*/
DCP (std::string directory);
- /** Read an existing DCP's data.
+ void read (bool require_mxfs = true);
+
+ /** Read an existing DCP's assets.
*
* The DCP's XML metadata will be examined, and you can then look at the contents
* of the DCP.
- *
- * @param require_mxfs true to throw an exception if MXF files are missing; setting to false
- * can be useful for testing, but normally it should be set to true.
*/
- void read (bool require_mxfs = true);
+ void read_assets ();
+
+ void read_cpls (bool require_mxfs = true);
/** Write the required XML files to the directory that was
* passed into the constructor.
@@ -145,6 +146,8 @@ private:
std::string asset_map;
};
+ Files _files;
+
/** the directory that we are writing to */
std::string _directory;
/** our CPLs */